package cmd

import (
	"fmt"
	"io"
	"net/http"
	"os"
	"regexp"
	"strconv"
	"strings"
)

var (
	url            string
	folderTitleUrl string
	max            int
	output         string
	chapter        int
	host           = "https://img4.qy0.ru"
)

func init() {
	rootCmd.PersistentFlags().StringVarP(&url, "url", "u", "", "除域名外的链接")
	rootCmd.PersistentFlags().IntVarP(&max, "max", "m", 1, "图片最大值")
	rootCmd.PersistentFlags().StringVarP(&output, "output", "o", "anime", "设置漫画抓取结果的保存位置，默认为当前用户的主目录下的 anime 文件夹")
	rootCmd.PersistentFlags().StringVarP(&folderTitleUrl, "folderTitleUrl", "t", "", "文件夹标题抓取链接")
	rootCmd.PersistentFlags().IntVarP(&chapter, "chapter", "c", 1, "指定章节，用于文件夹标题抓取")
}

func IfPathNotExistDoMkdir(path string) error {
	_, err := os.Stat(path)
	if err != nil || os.IsNotExist(err) {
		err := os.MkdirAll(path, 0777)
		if err != nil {
			return err
		}
	}

	return nil
}

func Execute() {
	if err := rootCmd.Execute(); err != nil {
		fmt.Println(err)
		os.Exit(1)
	}
}

// FindChapterTitle 解析文件夹标题
func FindChapterTitle(url string, num int) string {
	resp, err := http.Get(url)
	if err != nil {
		fmt.Println("请求文件夹标题失败:", err)
		return ""
	}

	defer func(Body io.ReadCloser) {
		err := Body.Close()
		if err != nil {
			fmt.Println("文件夹标题http请求关闭失败:", err)
			return
		}
	}(resp.Body)

	body, err := io.ReadAll(resp.Body)
	if err != nil {
		fmt.Println("文件夹标题读取失败:", err)
		return ""
	}

	content := string(body)
	re := regexp.MustCompile(`\\u7b2c` + strconv.Itoa(num) + `\\u8bdd (.+?)"`)
	matches := re.FindAllStringSubmatch(content, -1)

	if len(matches) == 0 {
		return ""
	}
	unquoted, err := strconv.Unquote(`"` + matches[0][1] + `"`)
	if err != nil {
		fmt.Println("文件夹标题转码失败:", err)
		return ""
	}

	replacements := map[string]string{
		"?": "？",
		":": "：",
		"!": "！",
	}
	unquoted = strings.TrimSpace(unquoted)
	for old, re := range replacements {
		unquoted = strings.ReplaceAll(unquoted, old, re)
	}

	return unquoted
}
